@@ -10,19 +10,20 @@ LOG_FILE = "edr.log"
 def get_console_handler():
     console_handler = logging.StreamHandler(sys.stdout)
     console_handler.setFormatter(FORMATTER)
+    console_handler.setLevel(logging.DEBUG if is_debug_mode_on() else logging.INFO)
     return console_handler
 
 
 def get_file_handler():
     file_handler = logging.FileHandler(LOG_FILE)
     file_handler.setFormatter(FORMATTER)
+    file_handler.setLevel(logging.DEBUG)
     return file_handler
 
 
 def get_logger(logger_name):
     logger = logging.getLogger(logger_name)
-    log_level = logging.DEBUG if is_debug_mode_on() else logging.INFO
-    logger.setLevel(log_level)
+    logger.setLevel(logging.DEBUG)
     logger.addHandler(get_console_handler())
     logger.addHandler(get_file_handler())
     # with this pattern, it's rarely necessary to propagate the error up to parent
